# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Test case module for Perl
Name:		perl-Test-Manifest
Version:	2.025
Release:	1.%{__distinit}%{__distvers}
License:	Artistic-2.0
URL:		https://metacpan.org/release/Test-Manifest
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Manifest-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.64
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Harness)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More) >= 1
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(File::Spec)
Requires:	perl(Test::Harness)

%description
MakeMaker assumes that you want to run all of the .t files in the t/ directory
in ascii-betical order during make test unless you say otherwise. This leads to
some interesting naming schemes for test files to get them in the desired
order.

You can specify any order or any files that you like, though, with the test
directive to WriteMakefile.

Test::Manifest looks in the t/test_manifest file to find out which tests you
want to run and the order in which you want to run them. It constructs the
right value for MakeMaker to do the right thing.

%prep
%setup -q -n Test-Manifest-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README.pod SECURITY.md
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Manifest.3*

%changelog
* Sun Jan  5 2025 Paul Howarth <paul@city-fan.org> - 2.025-1
- Update to 2.025
  - Refresh distro and move to BRIANDFOY
- Package new file SECURITY.md

* Tue Jan  9 2024 Paul Howarth <paul@city-fan.org> - 2.024-1
- Update to 2.024
  - Refresh distro

* Mon May 15 2023 Paul Howarth <paul@city-fan.org> - 2.023-5
- Use SPDX-format license tag

* Sun Jan  9 2022 Paul Howarth <paul@city-fan.org> - 2.023-1
- Update to 2.023
  - Fix a link in the README.pod

* Mon Jan 18 2021 Paul Howarth <paul@city-fan.org> - 2.022-1
- Update to 2.022
  - Freshen distro, remove Travis CI, add GitHub Actions
  - Fix parallel testing (CPAN RT#92604, GH#4)
- Drop support for EOL distributions prior to F-19, EL-7:
  - Drop workaround for building with ExtUtils::MakeMaker < 6.64
  - Drop compatibility with rpm < 4.9
  - Use %%license unconditionally

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 2.021-5
- Perl 5.30 rebuild

* Tue May  8 2018 Paul Howarth <paul@city-fan.org> - 2.021-1
- Update to 2.021
  - Clarify that it's the Artistic License 2.0
- License changed to Artistic 2.0
- Add workaround for building with ExtUtils::MakeMaker < 6.64

* Mon Apr  9 2018 Paul Howarth <paul@city-fan.org> - 2.02-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with ExtUtils::MakeMaker < 6.48

* Mon Oct  3 2016 Paul Howarth <paul@city-fan.org> - 2.02-5
- Classify buildreqs by usage
- Simplify find command using -delete

* Tue Sep  9 2014 Paul Howarth <paul@city-fan.org> - 2.02-1
- Update to 2.02
  - Fix a spelling mistake (CPAN RT#98288)
- Drop manpage patch, no longer needed
- Add patch to support building with ExtUtils::MakeMaker < 6.48

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.23-8
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.23-7
- BR: perl(ExtUtils::MakeMaker)
- Package LICENSE file
- No need to explicitly require perl(Exporter)

* Sat Jun 30 2012 Paul Howarth <paul@city-fan.org> - 1.23-6
- BR:/R: perl(File::Spec) and perl(Test::Harness)
- BR: perl(base), perl(Carp), perl(File::Spec::Functions) and perl(Test::More)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 1.23-5
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.23-4
- Rebuild for perl 5.12.1 in Rawhide

* Thu May 13 2010 Paul Howarth <paul@city-fan.org> - 1.23-3
- Fix dist tag for RHEL-6 Beta

* Sat Feb 13 2010 Paul Howarth <paul@city-fan.org> 1.23-2
- Add manual deps on perl(Exporter), used in "use base" clause
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro rather than our own %%{__chmod} incantation

* Mon Jul 27 2009 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - fix bug for missing file (should warn and skip, not pass to run_t_files)
  - file path and unlink fixes for VMS (CPAN RT#32061)
- Add patch to reinstate manpage, dropped upstream
- Define RPM macros in global scope

* Sat Nov 15 2008 Paul Howarth <paul@city-fan.org> - 1.22-2
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Mon Oct 29 2007 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22

* Fri Sep 28 2007 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Fri Feb 23 2007 Paul Howarth <paul@city-fan.org> - 1.17-1
- Update to 1.17
- Fix dist tags for FC7 onwards
- Remove %%{__perl_version} macro, used only once
- Remove %%{__perl_package} macro, used only twice
- Use search.cpan.org URLs
- Remove buildroot unconditionally in %%clean and %%install
- No need to look for empty .bs files in a noarch package
- Don't use macros in command paths, hardcode them instead
- Fix argument order for find with -depth
- Define %%{__id_u} in a more portable way
- Add buildreqs perl(Test::Pod) and perl(Test::Pod::Coverage)

* Fri Jul  8 2005 Paul Howarth <paul@city-fan.org> - 1.14-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Fri Apr  1 2005 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
- Tidy up spec file

* Mon May 10 2004 Paul Howarth <paul@city-fan.org> - 0.93-1
- Initial build
